import { useEffect, useRef, useState } from 'react';
import { Link } from 'wouter';
import { 
  Heart, 
  Users, 
  Globe, 
  Zap, 
  ChevronRight, 
  Play,
  CheckCircle,
  ArrowRight,
  MapPin,
  Calendar,
  Award
} from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Card, CardContent } from '@/components/ui/card';
import { useScrollAnimations } from '@/hooks/use-scroll-animations';
import { useTypewriter } from '@/hooks/use-typewriter';

// Import images
import patTerminalImg from '@assets/image_1749127850284.png';
import clinic1Img from '@assets/_DSC4041_1751942331144.jpg';
import clinic2Img from '@assets/_DSC4164_1751942331145.jpg';
import clinic3Img from '@assets/_DSC9994_1751942331145.jpg';
import mcImg from '@assets/MC_1751942115910.jpeg';
import modAImg from '@assets/ModA_1751942331145.jpeg';

const Home = () => {
  const [currentStat, setCurrentStat] = useState(0);
  const { displayText: typewriterText, isComplete } = useTypewriter({ 
    text: 'Bridging Healthcare Divides', 
    speed: 150, 
    delay: 500 
  });
  
  const statsData = [
    { number: '50,000+', label: 'Lives Impacted', icon: Heart },
    { number: '25', label: 'Communities Served', icon: MapPin },
    { number: '100+', label: 'Healthcare Workers Trained', icon: Users },
    { number: '5', label: 'Countries Reached', icon: Globe }
  ];

  const impactMetrics = [
    { value: '98%', label: 'Patient Satisfaction', description: "We're working all persons can access care without delay or distance barriers." },
    { value: '75%', label: 'Reduced Travel Time', description: 'Our systems are designed to cut travel time for critical care access, especially in remote areas.' },
    { value: '40+', label: 'Chronic Conditions', description: 'Every PAT is equipped with Data-Driven intelligent systems for triage management at scale.' },
    { value: '24/7', label: 'Healthcare Access', description: "We're building energy-independent systems that guarantee around-the-clock healthcare access" }
  ];

  // Initialize scroll animations
  useScrollAnimations();

  // Animated counter effect
  useEffect(() => {
    const interval = setInterval(() => {
      setCurrentStat(prev => (prev + 1) % statsData.length);
    }, 3000);
    return () => clearInterval(interval);
  }, []);

  return (
    <>
      {/* Hero Section - Critical Above-Fold Content */}
      <section className="relative min-h-screen flex items-center justify-center overflow-hidden pt-16 sm:pt-20 above-fold critical-resource" style={{ minHeight: '100vh', contain: 'layout' }}>
        <div className="absolute inset-0 bg-gradient-to-br from-background via-cream-50 to-accent/20"></div>
        
        <div className="relative z-10 section-container">
          <div className="grid lg:grid-cols-2 gap-8 lg:gap-12 items-center">
            <div className="space-y-6 lg:space-y-8 animate-fade-in-left preload-critical">
              <div className="space-y-4 lg:space-y-6">
                <h1 className="hero-text font-serif text-responsive-xxl font-bold text-foreground leading-tight font-optimized text-high-contrast" style={{ minHeight: '1.2em' }}>
                  <span className="typewriter-text" style={{ minHeight: '1.2em', minWidth: '20ch', display: 'inline-block' }}>
                    {typewriterText.includes('Divides') ? (
                      <>
                        {typewriterText.replace(' Divides', '')}
                        <span className="text-transparent bg-gradient-to-r from-primary to-gold bg-clip-text"> Divides</span>
                      </>
                    ) : (
                      typewriterText
                    )}
                    {!isComplete && <span className="animate-pulse text-primary">|</span>}
                  </span>
                </h1>
                <p className="text-responsive-lg text-muted-foreground font-light leading-relaxed font-optimized">
                  Revolutionary solar-powered Patient Access Terminals bringing 
                  world-class healthcare to remote communities across Africa.
                </p>
              </div>
              
              <div className="flex flex-col sm:flex-row gap-4">
                <Link href="#mission">
                  <Button className="button-enhanced btn-primary px-8 py-4 text-lg font-medium rounded-full group font-optimized">
                    Target Impact by 2026 ↓
                    <ChevronRight className="ml-2 h-5 w-5 group-hover:translate-x-1 transition-transform" />
                  </Button>
                </Link>
                <Link href="/donate">
                  <Button variant="outline" className="button-enhanced px-8 py-4 text-lg font-medium rounded-full border-2 border-primary text-primary hover:bg-primary hover:text-primary-foreground font-optimized">
                    Support Our Cause
                  </Button>
                </Link>
              </div>

              {/* Live Stats */}
              <div className="grid grid-cols-2 lg:flex lg:items-center lg:space-x-8 pt-8 gap-4 lg:gap-0">
                {statsData.map((stat, index) => {
                  const Icon = stat.icon;
                  return (
                    <div 
                      key={index}
                      className={`text-center transition-all duration-500 ${
                        currentStat === index ? 'scale-110 text-primary' : 'text-muted-foreground'
                      }`}
                    >
                      <Icon className="h-6 w-6 sm:h-8 sm:w-8 mx-auto mb-2" />
                      <div className="font-bold text-xl sm:text-2xl">{stat.number}</div>
                      <div className="text-xs sm:text-sm">{stat.label}</div>
                    </div>
                  );
                })}
              </div>
            </div>

            <div className="relative animate-fade-in-right preload-critical">
              <div className="relative">
                <div className="absolute inset-0 bg-gradient-to-tr from-primary/20 to-accent/30 rounded-3xl transform rotate-3"></div>
                <img 
                  src={patTerminalImg} 
                  alt="Solar-powered Patient Access Terminal"
                  className="relative z-10 w-full h-auto max-w-lg mx-auto rounded-2xl shadow-2xl image-optimized"
                  loading="eager"
                  decoding="async"
                  fetchpriority="high"
                />
                <div className="absolute -bottom-2 -right-2 sm:-bottom-4 sm:-right-4 bg-card rounded-xl p-3 sm:p-4 shadow-xl border border-border">
                  <div className="flex items-center space-x-2 sm:space-x-3">
                    <div className="w-3 h-3 bg-green-500 rounded-full animate-pulse"></div>
                    <span className="text-xs sm:text-sm font-medium">24/7 Online</span>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>

        {/* Scroll Indicator */}
        <div className="absolute bottom-8 left-1/2 transform -translate-x-1/2 animate-bounce">
          <div className="w-6 h-10 border-2 border-primary rounded-full flex justify-center">
            <div className="w-1 h-3 bg-primary rounded-full mt-2 animate-pulse"></div>
          </div>
        </div>
      </section>

      {/* Mission Section */}
      <section id="mission" className="section bg-card">
        <div className="section-container">
          <div className="grid lg:grid-cols-2 gap-16 items-center">
            <div className="space-y-8 scroll-animate" id="mission-content">
              <div className="space-y-4">
                <h2 className="font-serif text-4xl lg:text-5xl font-bold text-foreground">
                  Our Mission
                </h2>
                <div className="w-24 h-1 bg-gradient-to-r from-primary to-gold"></div>
              </div>
              
              <div className="space-y-6 text-lg text-muted-foreground leading-relaxed">
                <p>
                  Mary Global Health exists to bridge the healthcare divide in rural and underserved communities. 
                  We believe that geography should never determine access to quality healthcare.
                </p>
                <p>
                  Through our innovative Patient Access Terminals (PATs), we're revolutionizing healthcare 
                  delivery by bringing advanced medical technology directly to the communities that need it most.
                </p>
              </div>

              <div className="space-y-4">
                {[
                  'Eliminate healthcare access barriers',
                  'Empower local healthcare workers',
                  'Reduce maternal and infant mortality',
                  'Provide sustainable healthcare solutions'
                ].map((item, index) => (
                  <div key={index} className="flex items-center space-x-3">
                    <CheckCircle className="h-6 w-6 text-primary flex-shrink-0" />
                    <span className="text-lg">{item}</span>
                  </div>
                ))}
              </div>
            </div>

            <div className="grid grid-cols-2 gap-6 scroll-animate" id="mission-gallery">
              <img 
                src={clinic1Img} 
                alt="Community healthcare event"
                className="rounded-xl shadow-lg w-full h-64 object-cover"
              />
              <img 
                src={clinic2Img} 
                alt="Healthcare worker with community"
                className="rounded-xl shadow-lg w-full h-64 object-cover mt-8"
              />
            </div>
          </div>
        </div>
      </section>

      {/* Solution Section */}
      <section id="solution" className="section bg-background">
        <div className="section-container">
          <div className="text-center space-y-6 mb-16 scroll-animate" id="solution-header">
            <h2 className="font-serif text-4xl lg:text-5xl font-bold text-foreground">
              Our Solution
            </h2>
            <div className="w-24 h-1 bg-gradient-to-r from-primary to-gold mx-auto"></div>
            <p className="text-xl text-muted-foreground max-w-3xl mx-auto leading-relaxed">
              Solar-powered Patient Access Terminals (PATs) that bring advanced healthcare 
              technology directly to remote communities, ensuring 24/7 access to medical care.
            </p>
          </div>

          <div className="grid lg:grid-cols-3 gap-8 mb-16">
            {[
              {
                icon: Zap,
                title: 'Solar-Powered Technology',
                description: 'Sustainable energy solutions ensuring constant operation even in remote areas without grid electricity.',
                features: ['100% Solar Powered', 'Battery Backup', '24/7 Operation', 'Weather Resistant']
              },
              {
                icon: Heart,
                title: 'Comprehensive Health Monitoring',
                description: 'Advanced diagnostic capabilities for preventive care, chronic disease management, and emergency response.',
                features: ['Vital Signs Monitoring', 'Lab Diagnostics', 'Telemedicine Support', 'Health Records']
              },
              {
                icon: Users,
                title: 'Community Integration',
                description: 'Training local healthcare workers and integrating with existing healthcare systems for maximum impact.',
                features: ['Local Training Programs', 'Community Education', 'Healthcare Worker Support', 'System Integration']
              }
            ].map((feature, index) => {
              const Icon = feature.icon;
              return (
                <Card key={index} className="card-modern p-8 text-center scroll-animate" id={`feature-${index}`}>
                  <CardContent className="space-y-6">
                    <div className="w-16 h-16 bg-primary/10 rounded-full flex items-center justify-center mx-auto">
                      <Icon className="h-8 w-8 text-primary" />
                    </div>
                    <h3 className="font-serif text-2xl font-semibold text-foreground">
                      {feature.title}
                    </h3>
                    <p className="text-muted-foreground leading-relaxed">
                      {feature.description}
                    </p>
                    <ul className="space-y-2">
                      {feature.features.map((item, featureIndex) => (
                        <li key={featureIndex} className="flex items-center justify-center space-x-2 text-sm">
                          <CheckCircle className="h-4 w-4 text-primary flex-shrink-0" />
                          <span>{item}</span>
                        </li>
                      ))}
                    </ul>
                  </CardContent>
                </Card>
              );
            })}
          </div>

          {/* PAT Terminal Showcase */}
          <div className="grid lg:grid-cols-2 gap-16 items-center">
            <div className="scroll-animate" id="pat-showcase">
              <div className="relative overflow-hidden rounded-2xl shadow-2xl">
                <img 
                  src={patTerminalImg} 
                  alt="Patient Access Terminal - Solar-powered healthcare technology"
                  className="w-full h-auto transition-transform duration-300 hover:scale-105"
                  loading="eager"
                  decoding="sync"
                  style={{ 
                    objectFit: 'contain', 
                    width: '100%', 
                    height: 'auto',
                    display: 'block',
                    maxHeight: '600px'
                  }}
                />
                <div className="absolute inset-0 bg-gradient-to-t from-primary/10 to-transparent rounded-2xl pointer-events-none"></div>
              </div>
            </div>
            
            <div className="space-y-8 scroll-animate" id="pat-details">
              <div className="space-y-4">
                <h3 className="font-serif text-3xl font-bold text-foreground">
                  Patient Access Terminal (PAT)
                </h3>
                <p className="text-lg text-muted-foreground leading-relaxed">
                  Our flagship PAT units are engineered specifically for challenging environments, 
                  providing reliable healthcare access where it's needed most.
                </p>
              </div>

              <div className="grid grid-cols-2 gap-6">
                {[
                  { label: 'Solar Panels', value: '400W' },
                  { label: 'Battery Backup', value: '48hrs' },
                  { label: 'Operating Temp', value: '-10°C to 50°C' },
                  { label: 'Connectivity', value: '4G/5G + Satellite' }
                ].map((spec, index) => (
                  <div key={index} className="text-center p-4 bg-card rounded-lg border border-border">
                    <div className="font-bold text-2xl text-primary">{spec.value}</div>
                    <div className="text-sm text-muted-foreground">{spec.label}</div>
                  </div>
                ))}
              </div>

              <Link href="/products">
                <Button className="btn-primary px-8 py-3 font-medium rounded-full group">
                  Learn More About PATs
                  <ArrowRight className="ml-2 h-5 w-5 group-hover:translate-x-1 transition-transform" />
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Impact Section */}
      <section id="impact" className="section bg-gradient-to-br from-primary/5 via-background to-accent/5">
        <div className="section-container">
          <div className="text-center space-y-6 mb-16 scroll-animate" id="impact-header">
            <h2 className="font-serif text-4xl lg:text-5xl font-bold text-foreground">
              Impact Forecast
            </h2>
            <div className="w-24 h-1 bg-gradient-to-r from-primary to-gold mx-auto"></div>
            <p className="text-lg text-muted-foreground max-w-3xl mx-auto leading-relaxed">
              Our solutions are engineered to confront inequality at its source, creating sustainable, system-level change.
            </p>
          </div>

          {/* Impact Metrics */}
          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8 mb-16">
            {impactMetrics.map((metric, index) => (
              <Card key={index} className="card-modern p-6 text-center scroll-animate" id={`metric-${index}`}>
                <CardContent className="space-y-4">
                  <div className="font-serif text-4xl font-bold text-primary">
                    {metric.value}
                  </div>
                  <h3 className="font-semibold text-lg text-foreground">
                    {metric.label}
                  </h3>
                  <p className="text-xs text-muted-foreground">
                    {metric.description}
                  </p>
                </CardContent>
              </Card>
            ))}
          </div>

          {/* Community Stories */}
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div className="scroll-animate" id="community-story">
              <div className="relative overflow-hidden rounded-2xl shadow-lg">
                <img 
                  src={clinic3Img} 
                  alt="Community healthcare meeting showing real impact"
                  className="w-full h-96 object-cover transition-transform duration-300 hover:scale-105"
                  loading="eager"
                  decoding="sync"
                  style={{ 
                    objectFit: 'cover', 
                    width: '100%', 
                    height: '384px',
                    display: 'block'
                  }}
                />
                <div className="absolute inset-0 bg-gradient-to-t from-black/20 to-transparent"></div>
              </div>
            </div>
            
            <div className="space-y-8 scroll-animate" id="story-content">
              <div className="space-y-4">
                <h3 className="font-serif text-3xl font-bold text-foreground">
                  Real Stories, Real Impact
                </h3>
                <p className="text-lg text-muted-foreground leading-relaxed">
                  Our Patient Access Terminals serve as intelligent clinical triage assistants, 
                  revolutionizing access to care in underserved communities through AI-powered 
                  diagnostics, real-time specialist consultations, and comprehensive health monitoring.
                </p>
              </div>

              <blockquote className="border-l-4 border-primary pl-6 italic text-base text-muted-foreground">
                "Once deployed, the PAT terminal will change how care is delivered in underserved communities. Designed as a clinical triage assistant, it will instantly assess symptoms, prioritize critical cases, and link patients to remote specialists, reducing hours of travel to minutes of care."
                <footer className="not-italic font-semibold text-foreground mt-2">
                  — Dr. Kwabena.
                </footer>
              </blockquote>

              <div className="flex flex-col sm:flex-row gap-4">
                <Link href="/story">
                  <Button variant="outline" className="px-6 py-3 font-medium rounded-full border-2 border-primary text-primary hover:bg-primary hover:text-primary-foreground">
                    Read More Stories
                  </Button>
                </Link>
                <Link href="/donate">
                  <Button className="btn-primary px-6 py-3 font-medium rounded-full">
                    Join Our Mission
                  </Button>
                </Link>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Contact/CTA Section */}
      <section className="section bg-card">
        <div className="section-container">
          <div className="text-center space-y-8 scroll-animate" id="cta-section">
            <h2 className="font-serif text-4xl lg:text-5xl font-bold text-foreground">
              Ready to Make a Difference?
            </h2>
            <p className="text-xl text-muted-foreground max-w-3xl mx-auto leading-relaxed">
              Join us in bridging healthcare divides and transforming communities across Africa. 
              Your support helps us bring life-saving technology to those who need it most.
            </p>
            
            <div className="flex flex-col sm:flex-row gap-6 justify-center">
              <Link href="/donate">
                <Button className="btn-primary px-10 py-4 text-lg font-medium rounded-full group">
                  Donate Now
                  <Heart className="ml-2 h-5 w-5 group-hover:scale-110 transition-transform" />
                </Button>
              </Link>
              <Link href="/contact">
                <Button variant="outline" className="px-10 py-4 text-lg font-medium rounded-full border-2 border-primary text-primary hover:bg-primary hover:text-primary-foreground">
                  Get Involved
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>
    </>
  );
};

export default Home;
